flutter_rotation_sensor library
Classes
- Axis3
- Represents an axis of a 3D coordinate system, internally storing a unit vector that indicates the direction of the axis.
- AxisAngle
- A class representing an axis-angle rotation. The rotation is defined by an axis and an angle of rotation around that axis.
- CoordinateSystem
- An abstract class representing a standard 3-axis right-handed Cartesian coordinate system to express orientation data values.
- DeviceCoordinateSystem
- A coordinate system defined relative to the device's screen when the device is held in its default orientation, which is the orientation that the system first uses for its boot logo, or the orientation in which the hardware logos or markings are upright, or the orientation in which the cameras are at the top.
- DisplayCoordinateSystem
- A coordinate system that adapts to the device's current orientation. It adjusts based on the device's rotation.
- EulerAngles
- Represents the orientation as Euler angles, which are angles of rotation about each of the three principal axes. The sequence of rotations follows the order of azimuth (yaw), pitch, and roll. All angles are in radians. This plugin utilizes intrinsic Tait-Bryan angles, indicating that rotations are performed relative to the rotating reference frame of the device's coordinate system (XYZ axes).
- Matrix3
- A class representing a 3x3 matrix.
- OrientationEvent
- Represents an orientation event detected by sensors, providing information about the orientation of the device.
- Quaternion
- A class representing a quaternion.
- RotationSensor
- Provides access to the device's rotation sensor, offering a real-time stream of the device's orientation.
- SensorInterval
- Defines some common intervals for sensor data updates.
- TransformedCoordinateSystem
- A coordinate system that applies a transformation on top of an optional base coordinate system. If no base is provided, it defaults to the display coordinate system.
- Vector3
- A 3D vector class for representing and manipulating vectors in three-dimensional space.