AxisAngle class

A class representing an axis-angle rotation. The rotation is defined by an axis and an angle of rotation around that axis.

Annotations

Constructors

AxisAngle(Vector3 axis, double angle)
Constructs an AxisAngle.
const

Properties

angle double
The angle in radians.
final
axis Vector3
The axis represented by a Vector3.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQuaternion() Quaternion
Converts this axis-angle representation to a quaternion.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited