DisplayCoordinateSystem class

A coordinate system that adapts to the device's current orientation. It adjusts based on the device's rotation.

  • X axis: Horizontal, points to the right of the current UI orientation.
  • Y axis: Vertical, points up in current UI orientation.
  • Z axis: Points toward the outside of the screen. Coordinates behind the screen have negative Z values.
Inheritance

Constructors

DisplayCoordinateSystem()
factory

Properties

communicator ↔ NativeDeviceOrientationCommunicator?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
orientation ↔ NativeDeviceOrientation
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(OrientationEvent event) OrientationEvent
Applies the coordinate system transformation to the given orientation event.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited