EulerAngles class

Represents the orientation as Euler angles, which are angles of rotation about each of the three principal axes. The sequence of rotations follows the order of azimuth (yaw), pitch, and roll. All angles are in radians. This plugin utilizes intrinsic Tait-Bryan angles, indicating that rotations are performed relative to the rotating reference frame of the device's coordinate system (XYZ axes).

Inheritance

Constructors

EulerAngles(double azimuth, double pitch, double roll)
Constructs an EulerAngles.
factory

Properties

azimuth double
Angle of rotation about the -Z axis. This value represents the angle between the device's Y axis and the magnetic north pole (y-axis). When facing north, this angle is 0, when facing south, this angle is π. Likewise, when facing east, this angle is π/2, and when facing west, this angle is 3π/2. The range of values is 0(inclusive) to 2π(exclusive).
no setter
hashCode int
The hash code for this object.
no setterinherited
length double
The length (magnitude) of this vector.
no setterinherited
length2 double
The squared length of this vector.
no setterinherited
pitch double
Angle of rotation about the X axis. This value represents the angle between a plane parallel to the device's screen and a plane parallel to the ground. Assuming that the bottom edge of the device faces the user and that the screen is face-up, tilting the top edge of the device toward the sky creates a positive pitch angle. The range of values is -π/2(inclusive) to π/2(inclusive).
no setter
roll double
Angle of rotation about the Y axis. This value represents the angle between a plane perpendicular to the device's screen and a plane perpendicular to the ground. Assuming that the bottom edge of the device faces the user and that the screen is face-up, tilting the left edge of the device toward the sky creates a positive roll angle. The range of values is -π(exclusive) to π(inclusive).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
The x component of the vector.
no setterinherited
y double
The y component of the vector.
no setterinherited
yaw double
Angle of rotation about the -Z axis. This value represents the angle between the device's Y axis and the magnetic north pole (y-axis). When facing north, this angle is 0, when facing south, this angle is π. Likewise, when facing east, this angle is π/2, and when facing west, this angle is 3π/2. The range of values is 0(inclusive) to 2π(exclusive).
no setter
z double
The z component of the vector.
no setterinherited

Methods

apply(double f(double)) Vector3
Applies a function f to each component of this vector and returns a new Vector3.
inherited
cross(Vector3 o) Vector3
Computes the cross product of this vector with another Vector3.
inherited
dot(Vector3 o) double
Computes the dot product of this vector with another Vector3.
inherited
normalize() Vector3
Normalizes this vector.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRotationMatrix() Matrix3
Converts this Euler angles to a rotation matrix.
toString() String
A string representation of this object.
inherited

Operators

operator *(double s) Vector3
Multiplies this vector by a scalar.
inherited
operator +(Vector3 o) Vector3
Adds this vector with another Vector3.
inherited
operator -(Vector3 o) Vector3
Subtracts another Vector3 from this vector.
inherited
operator /(double s) Vector3
Divides this vector by a scalar.
inherited
operator ==(Object other) bool
Determines whether this vector is equal to another object. Returns true if the other object is an Vector3 with the same components.
inherited
operator unary-() Vector3
Negates this vector.
inherited