accuracy property

double accuracy
final

An estimated accuracy of the sensor data (in radians). The actual device orientation is expected to be within this margin of error. If the accuracy is unavailable, this value is -1. Accuracy information was introduced in Android SDK level 18, but not all devices support it. For iOS devices, this is always -1.

Implementation

final double accuracy;