coordinateSystem property
The coordinate system in which the orientation is expressed, represented as a 3x3 matrix.
Implementation
final Matrix3 coordinateSystem;
The coordinate system in which the orientation is expressed, represented as a 3x3 matrix.
final Matrix3 coordinateSystem;