TransformedCoordinateSystem class

A coordinate system that applies a transformation on top of an optional base coordinate system. If no base is provided, it defaults to the display coordinate system.

This transformation allows you to remap the coordinate axes according to your application's specific requirements. The new coordinate system is defined as:

  • X axis: Corresponds to the newX axis in the base coordinate system.
  • Y axis: Corresponds to the newY axis in the base coordinate system.
  • Z axis: Defined by the cross product of newX and newY axes in the base coordinate system, ensuring a right-handed coordinate system.
Inheritance

Constructors

TransformedCoordinateSystem(Axis3 newX, Axis3 newY, [CoordinateSystem? base])

Properties

base CoordinateSystem
final
hashCode int
The hash code for this object.
no setterinherited
newX Axis3
final
newY Axis3
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(OrientationEvent event) OrientationEvent
Applies the coordinate system transformation to the given orientation event.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited