AxisAngle class
A class representing an axis-angle rotation. The rotation is defined by an axis and an angle of rotation around that axis.
- Annotations
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toQuaternion(
) → Quaternion - Converts this axis-angle representation to a quaternion.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited