CoordinateSystem class abstract
An abstract class representing a standard 3-axis right-handed Cartesian coordinate system to express orientation data values.
Constructors
- CoordinateSystem()
-
const
- CoordinateSystem.device()
-
factory
- CoordinateSystem.display()
-
factory
- CoordinateSystem.transformed(Axis3 newX, Axis3 newY, [CoordinateSystem? base])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
OrientationEvent event) → OrientationEvent - Applies the coordinate system transformation to the given orientation event.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited