DeviceCoordinateSystem class
A coordinate system defined relative to the device's screen when the device is held in its default orientation, which is the orientation that the system first uses for its boot logo, or the orientation in which the hardware logos or markings are upright, or the orientation in which the cameras are at the top.
- X axis: Horizontal, points to the right of the screen in its default orientation.
- Y axis: Vertical, points up in device's default orientation.
- Z axis: Points toward the outside of the screen. Coordinates behind the screen have negative Z values.
- Inheritance
-
- Object
- CoordinateSystem
- DeviceCoordinateSystem
Constructors
- DeviceCoordinateSystem()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
OrientationEvent event) → OrientationEvent -
Applies the coordinate system transformation to the given orientation
event.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited