Matrix3 class
A class representing a 3x3 matrix.
- Annotations
Constructors
- Matrix3(double a, double b, double c, double d, double e, double f, double g, double h, double i)
- Constructs a Matrix3 with the specified elements.
- Matrix3.columns(Vector3 c0, Vector3 c1, Vector3 c2)
- Constructs a Matrix3 from the given column vectors.
- Matrix3.identity()
- Constructs an identity Matrix3.
- Matrix3.rotateX(double r)
-
Constructs a rotation matrix around the X-axis.
factory
- Matrix3.rotateY(double r)
-
Constructs a rotation matrix around the Y-axis.
factory
- Matrix3.rotateZ(double r)
-
Constructs a rotation matrix around the Z-axis.
factory
- Matrix3.rows(Vector3 r0, Vector3 r1, Vector3 r2)
- Constructs a Matrix3 from the given row vectors.
- Matrix3.zero()
- Constructs a Matrix3 with all elements initialized to zero.
Properties
- a → double
-
Returns the element at the first row and first column.
no setter
- b → double
-
Returns the element at the first row and second column.
no setter
- c → double
-
Returns the element at the first row and third column.
no setter
- d → double
-
Returns the element at the second row and first column.
no setter
- determinant → double
-
Returns the determinant of this matrix.
no setter
- e → double
-
Returns the element at the second row and second column.
no setter
- f → double
-
Returns the element at the second row and third column.
no setter
- g → double
-
Returns the element at the third row and first column.
no setter
- h → double
-
Returns the element at the third row and second column.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- i → double
-
Returns the element at the third row and third column.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trace → double
-
Returns the trace of this matrix.
no setter
Methods
-
adjoint(
) → Matrix3 - Returns the adjoint of this matrix.
-
apply(
double t(double)) → Matrix3 - Applies the given function to each element of the matrix.
-
column(
int c) → Vector3 - Returns the column at the given index.
-
invert(
) → Matrix3 - Returns the inverse of this matrix. If the determinant is zero, returns this matrix.
-
multiply(
Matrix3 o) → Matrix3 - Multiplies this matrix by the given matrix.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
row(
int r) → Vector3 - Returns the row at the given index.
-
toEulerAngles(
) → EulerAngles - Converts this matrix to Euler angles.
-
toQuaternion(
) → Quaternion - Converts this matrix to a quaternion.
-
toString(
) → String -
A string representation of this object.
override
-
transpose(
) → Matrix3 - Returns the transpose of this matrix.
Operators
-
operator *(
double s) → Matrix3 - Multiplies this matrix by the given scalar.
-
operator +(
Matrix3 o) → Matrix3 - Adds the given matrix to this matrix.
-
operator -(
Matrix3 o) → Matrix3 - Subtracts the given matrix from this matrix.
-
operator /(
double s) → Matrix3 - Divides this matrix by the given scalar.
-
operator ==(
Object other) → bool -
Determines whether this matrix is equal to another object. Returns true
if the other object is an Matrix3 with the same elements.
override
-
operator [](
int i) → double - Returns the element at the given index in row major order.
-
operator unary-(
) → Matrix3 - Returns the negation of this matrix.