gameInterval constant
Duration
const gameInterval
High-frequency update interval suitable for gaming applications. Provides more frequent updates to ensure game mechanics based on sensor data are responsive and provide a fluid experience.
Implementation
static const gameInterval = Duration(milliseconds: 20);